type_id_vtable

Function type_id_vtable 

pub const fn type_id_vtable(
    _id: TypeId,
    _trait: TypeId,
) -> Option<DynMetadata<*const ()>>
🔬This is a nightly-only experimental API. (core_intrinsics)
Check if a type represented by a TypeId implements a trait represented by a TypeId. It can only be called at compile time, the backends do not implement it. If it implements the trait the dyn metadata gets returned for vtable access.